//////////////////////////////////////////////////////////////////////////////

font comic_font, <comic20.pcx>, 34, 38;
font system2_font = <system2.pcx>, 20, 24; 

//////////////////////////////////////////////////////////////////////////////

var video_mode = 7; // 800x600
var video_depth = 32; // 32 bit mode

var dart_coords; // dart coordinates in the 3d world
var dart_speed; // dart speed

var random_x; // random movement target on x
var random_y; // random movement target on y
var counter = 0; // just a counter
var number_of_darts = 0; // number of darts fired so far
var display_darts = 5;
var display_50 = 0;
var display_25 = 0;
var display_10 = 0;
var score = 0; // score

//////////////////////////////////////////////////////////////////////////////

sound beep_sound = <beep.wav>;
sound fall_snd = <fall.wav>; // the score board falls on the ground
sound hit_snd = <hit.wav>; // the dart hits something (wall, board, etc)

//////////////////////////////////////////////////////////////////////////////

string board_wmb = <board.wmb>;
string dart_mdl = <dart.mdl>;

//////////////////////////////////////////////////////////////////////////////

bmap mouse_pcx = <mouse.pcx>; // the pointer is a picture of a dart

//////////////////////////////////////////////////////////////////////////////

text info_txt
{
	pos_x = 470;
	pos_y = 457;
	font = system2_font;
	string = "50x:\n25x:\n10x:\nFreccette:\nPunti:";

	flags = visible;
}

panel score_panel // a simple panel, without a bitmap, used for the score
{
	pos_x = 0;
	pos_y = 0;
	digits 670, 450, 3, comic_font, 1, display_50;	
	digits 670, 475, 3, comic_font, 1, display_25;	
	digits 670, 500, 3, comic_font, 1, display_10;	
	digits 670, 525, 3, comic_font, 1, display_darts;
	digits 670, 550, 3, comic_font, 1, score; // displays the score with 3 digits
	flags = refresh, d3d, visible;
}

//////////////////////////////////////////////////////////////////////////////

function move_dart(); // used during the movement
function stop_dart(); // the dart has impacted with something
function fall(); // the score board falls down
function compute_score(); // the dart has hit 50, 25 or 10

//////////////////////////////////////////////////////////////////////////////

function main()
{
	camera.arc = 60; // normal field of view (fov)
	fps_max = 30; // no need to have over 30 fps
	level_load (board_wmb);
	wait (2);
	mouse_map = mouse_pcx; // it's a 2d dart picture
	mouse_mode = 2; // the mouse can move freely
	mouse_pos.x = 372; // center of the screen
	mouse_pos.y = 272; // we substract 28 pixels = mouse pointer / 2 
	while (1)
	{
		if (key_t == 1) // press and hold "T" to get rid of the random dart movement, just for calibration
		{
			mouse_pos.x = pointer.x; // "normal" mouse movement
			mouse_pos.y = pointer.y; 
		}
		else
		{
			counter += 1;
			if (counter == 1) // set a random target then wait until it was reached
			{
				random_x = 20 - int(random(40)); // generate random numbers only once
				random_y = 20 - int(random(40)); // generate integer random numbers
			}
			if (mouse_pos.x < pointer.x + random_x) {mouse_pos.x += 1;} // move the mouse in the direction
			if (mouse_pos.x > pointer.x + random_x) {mouse_pos.x -= 1;} // of the random target
			if (mouse_pos.y < pointer.y + random_y) {mouse_pos.y += 1;} // on x and y
			if (mouse_pos.y > pointer.y + random_y) {mouse_pos.y -= 1;}
			if ((mouse_pos.x == pointer.x + random_x) && (mouse_pos.y == pointer.y + random_y)) // if the random target was reached
			{
				counter = 0; // generate a new pair of random numbers
			}
		}					
		if (mouse_left == 1 && number_of_darts < 5) // if we fire a new dart and we haven't fired all the darts yet
		{
			while (mouse_left == 1) {wait (1);} // wait until we release the left mouse button - disable autofire
			dart_coords.x = mouse_pos.x + 28; // 28 = mouse pointer bitmap / 2 
			dart_coords.y = mouse_pos.y + 28;
			dart_coords.z = 100; // 100 quants in front of the screen
			vec_for_screen(dart_coords, camera); // change 2d coords to 3d coords 
			ent_create(dart_mdl, dart_coords, move_dart); // create the dart
		}
		wait (1);
	}
}

function move_dart()
{
	wait (1);
	mouse_map = null; // hide the mouse pointer for now
	my.enable_entity = on; // the dart is sensitive to other entities
	my.enable_block = on; // and level blocks
	my.event = stop_dart; // if one of these event happen, the dart will stop
	my.skill1 = 0; // if the dart hits something, this skill will be set to 1
	dart_speed.x = 100; // main component of the dart speed
	dart_speed.y = (372 - mouse_pos.x) / 15; // 15 = experimental value, depends on dart_speed.x
	dart_speed.z = (272 - mouse_pos.y) / 15; // 15 = experimental value, depends on dart_speed.x
	dart_speed *= time; // keep the same speed at different frame rates - useful if your pc can't deliver at least 30 fps
	while (my.skill1 == 0) // loop until the dart has stopped its movement
	{
		move_mode = ignore_passable; // ignore passable entities
		ent_move (nullvector, dart_speed);
		wait (1);
	}
	// the dart has hit something here
	mouse_map = mouse_pcx; // restore the mouse pointer bitmap
}

function stop_dart() // the dart has hit something
{
	my.skill1 = 1; // set skill1 to 1 in order to stop the movement
	wait (1);
	snd_play (hit_snd, 50, 0);
	my.passable = on; // other darts should be able to pass through this dart
	number_of_darts += 1; // another dart was fired
	display_darts -= 1;
	while (number_of_darts < 5) {wait (1);} // wait until all the darts are fired
	while (camera.arc > 20) // zoom in
	{
		camera.arc -= 0.2 * time; // all the darts substract from this value in order to keep the things simple
		wait (1);
	}
	while (key_any == 0) {wait (1);} // wait until the player presses any key
	ent_remove (me); // remove the darts that were fired
	while (camera.arc < 60) // zoom out
	{
		camera.arc += 0.2 * time; // all the darts add to this value in order to keep the things simple
		wait (1);
	}
	camera.arc = 60; // set camera.arc to 60 (could be set to 60.1 or so when it gets out of the while loop)
	number_of_darts = 0; // now we can fire 5 brand new darts
	display_darts = 5;	
   display_50 = 0;
   display_25 = 0;
   display_10 = 0;	
	score = 0; // reset the score
}

	
action score_board // a sprite
{
	my.oriented = on; // oriented sprite
	my.enable_impact = on; // sensitive on impact with other entities
	my.event = fall; // if hit, runs function fall()
}

function fall() // the score board falls when you shoot it
{
	while (my.z > -500) // decrease my height until it reaches a value below -500 quants on z
	{
		my.z -= 50 * time; // change 50 to alter the speed
		wait (1);
	}
	snd_play (fall_snd, 50, 0); // play a sound when it has stopped moving (the player will think that it has hit the floor..)
}

action got_50 // attached to the center of the dartboard
{
	my.skill1 = 50; // set the score for it in skill1
	my.enable_impact = on; // sensitive on impact
	my.event = compute_score; // here's what happens if a dart impacts with it
}

action got_25 // same things here
{
	my.skill1 = 25;
	my.enable_impact = on;
	my.event = compute_score;
}

action got_10 // same things here
{
	my.skill1 = 10;
	my.enable_impact = on;
	my.event = compute_score;
}

action got_0 // same things here
{
	my.skill1 = 0;
	my.enable_impact = on;
	my.event = fall;
}

function compute_score() // runs if the dart hits one of the rings that add points to the score
{
	//score += my.skill1; // add the content of skill1 to the var named score
	
	if(my.skill1 == 10) 
	{
		score += my.skill1; // add the content of skill1 to the var named score
		display_10 += 1;
	}
	if(my.skill1 == 25) 
	{
		score += my.skill1; // add the content of skill1 to the var named score
		display_25 += 1;
	}
	if(my.skill1 == 50) 
	{
		score += my.skill1; // add the content of skill1 to the var named score
		display_50 += 1;
	}
}
